@@ -430,13 +430,8 @@ sub parse_feature_name {
   }
 
   my ($class,$ref,$start,$stop);
-  if ( ($name !~ /\.\./ and $name =~ /([\w._\/-]+):\s*(-?[-e\d.]+)\s*,\s*(-?[-e\d.]+)\s*$/) or
-      $name =~ /([\w._\/-]+):\s*(-?[-e\d,.]+?)\s*(?:-|\.\.)\s*(-?[-e\d,.]+)\s*$/) {
-    $ref  = $1;
-    $start = $2;
-    $stop  = $3;
-    $start =~ s/,//g; # get rid of commas
-    $stop  =~ s/,//g;
+  if (my @a = $self->is_chromosome_region($name)) {
+      ($ref,$start,$stop) = @a;
   }
 
   elsif ($name =~ /^(\w+):([^:]+)$/) {
@@ -450,6 +445,21 @@ sub parse_feature_name {
   return ($ref,$start,$stop,$class);
 }
 
+sub is_chromosome_region {
+    my $self = shift;
+    my $name = shift;
+    if ( ($name !~ /\.\./ and $name =~ /([\w._\/-]+):\s*(-?[-e\d.]+)\s*,\s*(-?[-e\d.]+)\s*$/) or
+	 $name =~ /([\w._\/-]+):\s*(-?[-e\d,.]+?)\s*(?:-|\.\.)\s*(-?[-e\d,.]+)\s*$/) {
+	my $ref  = $1;
+	my $start = $2;
+	my $stop  = $3;
+	$start =~ s/,//g; # get rid of commas
+	$stop  =~ s/,//g;
+	return ($ref,$start,$stop);
+    }
+    return;
+}
+
 =head2 $whole = $db->whole_segment ($segment,$settings);
 
 Given a detail segment, return the whole seq_id that contains it
